{
  description = "A Nix-flake-based Bun development environment";

  inputs.nixpkgs.url = "https://flakehub.com/f/NixOS/nixpkgs/0.1.*.tar.gz";

  outputs = { self, nixpkgs }:
    let
      supportedSystems = [ "x86_64-linux" "aarch64-linux" "x86_64-darwin" "aarch64-darwin" ];
      forEachSupportedSystem = f: nixpkgs.lib.genAttrs supportedSystems (system: f {
        pkgs = import nixpkgs { inherit system; };
      });
    in
    {
      devShells = forEachSupportedSystem ({ pkgs }: {
        default = pkgs.mkShell {
          packages = with pkgs; [ 
            # Frontend
            bun
            sqlite
            sqls
            sql-studio
            # Backend
            dotnetCorePackages.sdk_9_0
            dotnetCorePackages.aspnetcore_9_0
            nuget

            # LSP
            typescript-language-server
          ];
          shellHook = ''
            export PATH=$PATH:$HOME/.bun/bin
          '';
          
        };
      });
    };
}
